<?php

namespace Dobley;

abstract class ActionController extends Controller
{
	/**
	 * View Data
	 *
	 * An object to hold vars we want accessible in the view
	 *
	 * @var object
	 */
	public $viewData;

	/**
	 * Constructor
	 */
	public function __contruct()
	{
		$this->viewData = new stdClass();
	}

	/**
	 * Dispatch Action
	 *
	 * Calls the controller action method then renders the view
	 *
	 * @param string $controller
	 * @param string $action
	 * @throws \Exception if controller action does not exist
	 */
	public function dispatchAction($controller, $action)
	{
		$actionMethod = $action . "Action";
		try
		{
			if(!method_exists($this, $actionMethod)) {
			  throw new \Exception("Missing Action: " . $actionMethod . " does not exist.");
			}
		}
		catch (\Exception $e)
		{
			echo $e->getMessage();
			exit();
		}

		// Run the action
		$this->$actionMethod();
		// Then display its view
		$this->displayView($controller, $action);
	}

	/**
	 * Display View
	 *
	 * Displays the corresponding view for the action
	 *
	 * @param type $controller
	 * @param type $action
	 * @throws \Exception if the view does not exist
	 */
	public function displayView($controller, $action)
	{
		try
		{
			if(!is_readable(VIEW_PATH . "/" . $controller . "/" . $action . ".php")) {
				throw new \Exception("Missing View: " . $action . " view does not exist or is not readable.");
			}
		}
		catch (\Exception $e)
		{
			echo $e->getMessage();
			exit();
		}
		include VIEW_PATH . "/" . $controller . "/" . $action . ".php";
	}
}