<?php

namespace Dobley;

class ApplicationBootstrap
{
	/**
	 * Constructor
	 */
	public function __construct()
	{
		$this->_init();
	}

	/**
	 * Init
	 *
	 * Run the init functions that we have defined
	 */
	protected function _init()
	{
		$this->_initPaths();
		$this->_initAutoLoader();
		$this->_initFrontController();
	}

	/**
	 * Init Paths
	 *
	 * Defines various paths as constants as a convenience
	 */
	protected function _initPaths()
	{
		try {
			if(!defined("APPLICATION_PATH")) {
				throw new \Exception("APPLICATION_PATH is not defined: Cannot proceed without APPLICATION_PATH.");
			}
		}
		catch (\Exception $e)
		{
			echo $e->getMessage();
			exit();
		}

		if(!defined("LIB_PATH")) {
			define("LIB_PATH", APPLICATION_PATH . "/lib");
		}

		if(!defined("CONTROLLER_PATH")) {
			define("CONTROLLER_PATH", APPLICATION_PATH . "/controller");
		}

		if(!defined("VIEW_PATH")) {
			define("VIEW_PATH", APPLICATION_PATH . "/view/template");
		}
	}

	/**
	 * Init AutoLoader
	 */
	protected function _initAutoLoader()
	{
		require_once LIB_PATH . "/AutoLoader.php";
		$autoLoader = new AutoLoader();
		if(!$autoLoader instanceof AutoLoader) {
			throw new \Exception("Could not load AutoLoader");
			exit();
		}
	}

	/**
	 * Init FrontController
	 *
	 * Makes an instance of the FrontController available to the entire application
	 */
	protected function _initFrontController()
	{
		FrontController::getInstance();
	}
}